--[[
RP_CombatDice v2.5.2 - RP Dice Combat System.
Copyright (C) 2012-2015 Michel R Vaillancourt (Warlock Kassaria) - kassaria_warlock_soe@wolfstar.ca

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
]]--

-- ---------------------------- --
--Core Functions Code
--
local ADDON_NAME, T = ...;

local _, _, _, tocversion = GetBuildInfo();
T._tocversion = tocversion;

T.RP_CombatDice = LibStub("AceAddon-3.0"):NewAddon("RP Combat Dice", "AceConsole-3.0");
local RPCD = T.RP_CombatDice;

-- ---------------------------- --
--gets & sets code
function RPCD:GetRPCD_CharIsMeleeCombat()
  return self.db.char.RPCD_CharIsMeleeCombat
end

function RPCD:SetRPCD_CharIsMeleeCombat(i, newValue)
  self.db.char.RPCD_CharIsMeleeCombat = newValue
  RPCD:SaySetSkills()
end

--
function RPCD:GetRPCD_CharIsRangedCombat()
	return self.db.char.RPCD_CharIsRangedCombat
end

function RPCD:SetRPCD_CharIsRangedCombat(i, newValue)
	self.db.char.RPCD_CharIsRangedCombat = newValue
	RPCD:SaySetSkills()
end

--
function RPCD:GetRPCD_CharIsSpellCombat()
  return self.db.char.RPCD_CharIsSpellCombat
end

function RPCD:SetRPCD_CharIsSpellCombat(i, newValue)
  self.db.char.RPCD_CharIsSpellCombat = newValue
  RPCD:SaySetSkills()
end

--
function RPCD:GetRPCD_CharIsHealer()
	return self.db.char.RPCD_CharIsHealer
end

function RPCD:SetRPCD_CharIsHealer(i, newValue)
	self.db.char.RPCD_CharIsHealer = newValue
	RPCD:SaySetSkills()
end

--
function RPCD:GetRPCD_CharIsLore()
	return self.db.char.RPCD_CharIsLore
end

function RPCD:SetRPCD_CharIsLore(i, newValue)
	self.db.char.RPCD_CharIsLore = newValue
	RPCD:SaySetSkills()
end

--
function RPCD:GetRPCD_CharIsSocial()
  return self.db.char.RPCD_CharIsSocial
end

function RPCD:SetRPCD_CharIsSocial(i, newValue)
  self.db.char.RPCD_CharIsSocial = newValue
  RPCD:SaySetSkills()
end

--
function RPCD:GetRPCD_CharIsWellRounded()
	return self.db.char.RPCD_CharIsWellRounded
end

function RPCD:SetRPCD_CharIsWellRounded(i, newValue)
	self.db.char.RPCD_CharIsWellRounded = newValue
	RPCD:SaySetSkills()
end

--
--
function RPCD:GetRPCD_HasSignatureItem()
  return self.db.char.RPCD_HasSignatureItem
end

function RPCD:SetRPCD_HasSignatureItem(i, newValue)
  self.db.char.RPCD_HasSignatureItem = newValue
  RPCD:SaySetSkills()
end

--
function RPCD:GetRPCD_HasSpellBuff()
  return self.db.char.RPCD_HasSpellBuff
end

function RPCD:SetRPCD_HasSpellBuff(i, newValue)
  self.db.char.RPCD_HasSpellBuff = newValue
  RPCD:SaySetSkills()
end

--Function for the /RPCD command:
function RPCD:DoRP_CombatDice(msg)

	if msg ~= "" then
		--If message is blank, don't annoy the local group
    -- /RPCD l investigating the metal monster

    task =  RPCD:isubstr(msg, 1, 1)
    reason = RPCD:isubstr(msg, 2, 199)

    --set basic reason word
    local reason_word = "unknown"

    if task == 'r' then
      reason_word = "Ranged Combat"
    end
    if task == 'm' then
      reason_word = "Melee Combat"
    end
    if task == 's' then
      reason_word = "Spell Combat"
    end
    if task == 'h' then
      reason_word = "Healing"
    end
    if task == 'l' then
      reason_word = "Lore / Research"
    end
    if task == 'c' then
      reason_word = "Charm / Social"
    end
    if task == 'o' then
      reason_word = "Other / Misc"
    end

    --set up base modifiers condition
		local modifier_list = ""
		local modifer_value = 0

		--throw some dice
		local die1 = math.random(1,10)
		local die2 = math.random(1,10)
		local baseRoll = die1 + die2

		--Add applicable modifiers
    if self.db.char.RPCD_CharIsMeleeCombat and task == 'm' then
      modifier_list = modifier_list.."+ 2 (Melee Combat) "
      modifer_value = modifer_value + 2
    end

    if self.db.char.RPCD_CharIsRangedCombat and task == 'r' then
      modifier_list = modifier_list.."+ 2 (Ranged Combat) "
      modifer_value = modifer_value + 2
    end

    if self.db.char.RPCD_CharIsSpellCombat and task == 's' then
      modifier_list = modifier_list.."+ 2 (Spell Combat) "
      modifer_value = modifer_value + 2
    end

    if self.db.char.RPCD_CharIsHealer and task == 'h' then
      modifier_list = modifier_list.."+ 2 (Healer) "
      modifer_value = modifer_value + 2
    end

    if self.db.char.RPCD_CharIsLore and task == 'l' then
      modifier_list = modifier_list.."+ 2 (Lore & Research) "
      modifer_value = modifer_value + 2
    end

    if self.db.char.RPCD_CharIsSocial and task == 'c' then
      modifier_list = modifier_list.."+ 2 (Charm & Social) "
      modifer_value = modifer_value + 2
    end

    if self.db.char.RPCD_CharIsWellRounded then
      modifier_list = modifier_list.."+ 1 (Well Rounded) "
      modifer_value = modifer_value + 1
    end

    if self.db.char.RPCD_HasSignatureItem then
      modifier_list = modifier_list.."+ 1 (Signature Item) "
      modifer_value = modifer_value + 1
    end

    if self.db.char.RPCD_HasSpellBuff then
      modifier_list = modifier_list.."+ 1 (Potion or Magic) "
      modifer_value = modifer_value + 1
    end

    if self.db.char.RPCD_doApplyWoundLevelDM then
      local wl_dm = RPCD:getDiceModifierByWoundLevel()

      modifier_list = modifier_list .. wl_dm .. " (Injuries) "
      modifer_value = modifer_value + wl_dm
    end

		--Build text string to use for the emote.
		local emotestring = "makes a 2d10 roll of "..baseRoll.." "
		local totalRoll = 0
	  totalRoll = baseRoll + modifer_value

		if modifer_value ~= 0 then
		  --if we have a DM, factor it in
		  emotestring = emotestring..modifier_list
	  else
	    emotestring = emotestring.." with no modifiers "
	  end

	  --tack on the total
		emotestring = emotestring .. " for a total of " .. totalRoll .. " on a " .. reason_word .. " task to try to " .. reason

		--check for special effect
		if totalRoll <= 3 then
		  emotestring = "*CRITFAIL* :"..emotestring
	  end
	  if totalRoll >= 20 then
		  emotestring = "*CRITSUCCESS* :"..emotestring
	  end

    --get active story-teller tag and apply
    if RPCD:GetRPCD_doPostAsStoryTeller() then
      emotestring = "[Rolling As " .. RPCD:GetRPCD_StoryTellerTagMarker() .. "] " .. emotestring
    end

		--Send the emote.
		SendChatMessage(emotestring, string.upper(RPCD:getPostToChannel()) )

	else
		--no message, handle that
		RPCD:NoMsg()
	end
end

--Function for blank message handling
function RPCD:NoMsg()
  --pop a reminder.
  if self.db.global.RPCD_SaidHelp == 0 then
    RPCD:Print("You might have forgotten roll description.")
    RPCD:Print("Use:  /RPCD <task> <reason>")
    RPCD:Print("'task' must be one of 'm', 'r', 's', 'h', 'l', 'c' or 'o'")
    self.db.global.RPCD_SaidHelp = 1
  end

  --Define text to use for the emote.
  local emotestring = "[ ... is getting ready to make a roll, please hold ...] "

  --Send the emote.
  SendChatMessage(emotestring, string.upper(RPCD:getPostToChannel()) )
end

--Function to print current enabled skills
function RPCD:SaySetSkills()
  local activeSkills = ""

  if self.db.char.RPCD_CharIsMeleeCombat then
    activeSkills = activeSkills.." [Melee Fighter]"
  end

  if self.db.char.RPCD_CharIsRangedCombat then
    activeSkills = activeSkills.." [Ranged Fighter]"
  end

  if self.db.char.RPCD_CharIsSpellCombat then
    activeSkills = activeSkills.." [Spell Fighter]"
  end

  if self.db.char.RPCD_CharIsHealer then
    activeSkills = activeSkills.." [Healer]"
  end

  if self.db.char.RPCD_CharIsLore then
    activeSkills = activeSkills.." [Lore & Research]"
  end

  if self.db.char.RPCD_CharIsSocial then
    activeSkills = activeSkills.." [Charm & Social]"
  end

  if self.db.char.RPCD_CharIsWellRounded then
    activeSkills = activeSkills.." [Well Rounded]"
  end

  if self.db.char.RPCD_HasSignatureItem then
    activeSkills = activeSkills.." [Signature Item]"
  end

  if self.db.char.RPCD_HasSpellBuff then
    activeSkills = activeSkills.." [Potion or Magic]"
  end

  RPCD:Print("Profiles active: " .. activeSkills)
end

--Function to give a bried explaination
function RPCD:DoRP_SayDiffList()
  RPCD:Print("A roll of 2 or 3 is a 'fumble'")
  RPCD:Print("9+ is easy for an unskilled person")
  RPCD:Print("11+ is challenging for an unskilled person")
  RPCD:Print("13+ is very difficult for an unskilled person")
  RPCD:Print("A roll of 20+ is a 'critical success'")
end

-- end of file --
