--[[
RP_CombatDice v2.5.2 - RP Dice Combat System.
Copyright (C) 2012-2015 Michel R Vaillancourt (Warlock Kassaria) - kassaria_warlock_soe@wolfstar.ca

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
]]--

--
--health_manager Functions Code
local ADDON_NAME, T = ...;
local RPCD = T.RP_CombatDice;

--
--get and set functions
function RPCD:GetRPCD_doApplyWoundLevelDM( ... )
  return self.db.char.RPCD_doApplyWoundLevelDM
end

function RPCD:SetRPCD_doApplyWoundLevelDM(i, newValue)
  self.db.char.RPCD_doApplyWoundLevelDM = newValue
end

function RPCD:GetWoundLevel()
  return self.db.global.RPCD_wound_level
end

function RPCD:SetHealthLevel(new_value)
  self.db.global.RPCD_wound_level = new_value
end

--
--increase or decrease the wound level per tap
function RPCD:InflictRPWound()
  SendChatMessage(" takes damage ...", string.upper(RPCD:getPostToChannel() ))

  local wound_level = RPCD:GetWoundLevel()

  if wound_level < 13 then
    RPCD:SetHealthLevel(wound_level +1 )
  end

  RPCD:SayHealthStatus()
end

function RPCD:ApplyRPHeal()
  SendChatMessage(" is healed ...", string.upper(RPCD:getPostToChannel() ))

  local wound_level = RPCD:GetWoundLevel()

  if wound_level > 0 then
    RPCD:SetHealthLevel(wound_level -1 )
  end

  RPCD:SayHealthStatus()
end

--
--generate a human-friendly status of wound level
function RPCD:getWoundLevelText(wound_level)

  local status_table = {}

  status_table[0] = "Healthy"
  status_table[1] = "Healthy"
  status_table[2] = "Slightly Wounded"
  status_table[3] = "Slightly Wounded"
  status_table[4] = "Seriously Wounded"
  status_table[5] = "Seriously Wounded"
  status_table[6] = "Greviously Wounded"
  status_table[7] = "Greviously Wounded"
  status_table[8] = "suffering from Devastating Wounds"
  status_table[9] = "suffering from Devastating Wounds"

  local status_text = type(status_table[wound_level]) == "function" and status_table[wound_level]() or status_table[wound_level] or "Unconcious"

  return status_text

end

--
function RPCD:SayHealthStatus()

  local wound_level = RPCD:GetWoundLevel()
  local status_text  = RPCD:getWoundLevelText(wound_level)

  local info_string =  " is currently " .. status_text .. " (" .. wound_level .. " wounds)."

  SendChatMessage(info_string, string.upper(RPCD:getPostToChannel() ))

end

--
--generate a math-based die-roll modifier based on current wound level
function RPCD:getDiceModifierByWoundLevel()

  local dm = 0
  local wound_level = RPCD:GetWoundLevel()

  if wound_level > 0 then
    dm = math.floor(wound_level / 2) * -1
  end

  return dm
end

--
--on query tell just the player how bad a mess they are
function RPCD:CheckWoundsLocal()
  local wound_level = RPCD:GetWoundLevel()
  local status_text = RPCD:getWoundLevelText(wound_level)
  local playerName  = UnitName("player")

  local tag_string  = RPCD:text_cyan(" Wounds Info: ")
  local block_text  = status_text .. " (" .. wound_level .. " wounds)"
  local colored_status_text = block_text

  if wound_level <= 1 then
    colored_status_text = RPCD:text_green(block_text)
  elseif wound_level >= 2 and wound_level <= 3 then
    colored_status_text = RPCD:text_cyan(block_text)
  elseif wound_level >= 4 and wound_level <= 5 then
    colored_status_text = RPCD:text_yellow(block_text)
  elseif wound_level >= 6 then
    colored_status_text = RPCD:text_red(block_text)
  end

  local info_string =  tag_string .. playerName .. " is currently " .. colored_status_text .. "."

  RPCD:Print(info_string)

end

--
--Function to give a bried explaination
function RPCD:DoRP_SayWoundList()

  RPCD:Print(" 0 - 1 wounds is " .. RPCD:text_green(RPCD:getWoundLevelText(1)))
  RPCD:Print(" 2 - 3 wounds is " .. RPCD:text_cyan(RPCD:getWoundLevelText(3)))
  RPCD:Print(" 4 - 5 wounds is " .. RPCD:text_yellow(RPCD:getWoundLevelText(5)))
  RPCD:Print(" 6 - 7 wounds is " .. RPCD:text_red(RPCD:getWoundLevelText(7)))
  RPCD:Print(" 8 - 9 wounds is " .. RPCD:text_red(RPCD:getWoundLevelText(9)))
  RPCD:Print(" 10 or more wounds is " .. RPCD:text_red(RPCD:getWoundLevelText(11)))

  RPCD:Print(" If enabled, the current wounds / 2 is applied as a negative modifier to die rolls.")

end

-- end of file --
